@@ -251,7 +251,7 @@ class AttachedClustersAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Creates a new
         [AttachedCluster][google.cloud.gkemulticloud.v1.AttachedCluster]
-        resource on a given GCP project and region.
+        resource on a given Google Cloud Platform project and region.
 
         If successful, the response contains a newly created
         [Operation][google.longrunning.Operation] resource that can be
@@ -759,7 +759,8 @@ class AttachedClustersAsyncClient:
 
                 See `Resource
                 Names <https://cloud.google.com/apis/design/resource_names>`__
-                for more details on GCP resource names.
+                for more details on Google Cloud Platform resource
+                names.
 
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -884,7 +885,8 @@ class AttachedClustersAsyncClient:
 
                 See `Resource
                 Names <https://cloud.google.com/apis/design/resource_names>`__
-                for more details on GCP resource names.
+                for more details on Google Cloud Platform resource
+                names.
 
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -1027,7 +1029,8 @@ class AttachedClustersAsyncClient:
 
                 See `Resource
                 Names <https://cloud.google.com/apis/design/resource_names>`__
-                for more details on GCP resource names.
+                for more details on Google Cloud Platform resource
+                names.
 
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -1291,7 +1294,7 @@ class AttachedClustersAsyncClient:
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
             attached_cluster_id (:class:`str`):
-                Required. A client provided ID the resource. Must be
+                Required. A client provided ID of the resource. Must be
                 unique within the parent resource.
 
                 The provided ID will be part of the
@@ -1307,7 +1310,7 @@ class AttachedClustersAsyncClient:
                 field must be the Membership id.
 
                 Membership names are formatted as
-                ``resource name formatted as``\ projects//locations//memberships/\`.
+                ``projects/<project-id>/locations/<region>/memberships/<membership-id>``.
 
                 This corresponds to the ``attached_cluster_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
