@@ -495,7 +495,7 @@ class AttachedClustersClient(metaclass=AttachedClustersClientMeta):
     ) -> operation.Operation:
         r"""Creates a new
         [AttachedCluster][google.cloud.gkemulticloud.v1.AttachedCluster]
-        resource on a given GCP project and region.
+        resource on a given Google Cloud Platform project and region.
 
         If successful, the response contains a newly created
         [Operation][google.longrunning.Operation] resource that can be
@@ -1003,7 +1003,8 @@ class AttachedClustersClient(metaclass=AttachedClustersClientMeta):
 
                 See `Resource
                 Names <https://cloud.google.com/apis/design/resource_names>`__
-                for more details on GCP resource names.
+                for more details on Google Cloud Platform resource
+                names.
 
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -1119,7 +1120,8 @@ class AttachedClustersClient(metaclass=AttachedClustersClientMeta):
 
                 See `Resource
                 Names <https://cloud.google.com/apis/design/resource_names>`__
-                for more details on GCP resource names.
+                for more details on Google Cloud Platform resource
+                names.
 
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -1253,7 +1255,8 @@ class AttachedClustersClient(metaclass=AttachedClustersClientMeta):
 
                 See `Resource
                 Names <https://cloud.google.com/apis/design/resource_names>`__
-                for more details on GCP resource names.
+                for more details on Google Cloud Platform resource
+                names.
 
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -1510,7 +1513,7 @@ class AttachedClustersClient(metaclass=AttachedClustersClientMeta):
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
             attached_cluster_id (str):
-                Required. A client provided ID the resource. Must be
+                Required. A client provided ID of the resource. Must be
                 unique within the parent resource.
 
                 The provided ID will be part of the
@@ -1526,7 +1529,7 @@ class AttachedClustersClient(metaclass=AttachedClustersClientMeta):
                 field must be the Membership id.
 
                 Membership names are formatted as
-                ``resource name formatted as``\ projects//locations//memberships/\`.
+                ``projects/<project-id>/locations/<region>/memberships/<membership-id>``.
 
                 This corresponds to the ``attached_cluster_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -1594,7 +1597,7 @@ class AttachedClustersClient(metaclass=AttachedClustersClientMeta):
         # Done; return the response.
         return response
 
-    def __enter__(self):
+    def __enter__(self) -> "AttachedClustersClient":
         return self
 
     def __exit__(self, type, value, traceback):
