@@ -517,7 +517,7 @@ class AwsClustersClient(metaclass=AwsClustersClientMeta):
     ) -> operation.Operation:
         r"""Creates a new
         [AwsCluster][google.cloud.gkemulticloud.v1.AwsCluster] resource
-        on a given GCP project and region.
+        on a given Google Cloud Platform project and region.
 
         If successful, the response contains a newly created
         [Operation][google.longrunning.Operation] resource that can be
@@ -903,7 +903,8 @@ class AwsClustersClient(metaclass=AwsClustersClientMeta):
 
                 See `Resource
                 Names <https://cloud.google.com/apis/design/resource_names>`__
-                for more details on GCP resource names.
+                for more details on Google Cloud Platform resource
+                names.
 
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -1014,7 +1015,8 @@ class AwsClustersClient(metaclass=AwsClustersClientMeta):
 
                 See `Resource
                 Names <https://cloud.google.com/apis/design/resource_names>`__
-                for more details on GCP resource names.
+                for more details on Google Cloud Platform resource
+                names.
 
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -1148,7 +1150,8 @@ class AwsClustersClient(metaclass=AwsClustersClientMeta):
 
                 See `Resource
                 Names <https://cloud.google.com/apis/design/resource_names>`__
-                for more details on GCP resource names.
+                for more details on Google Cloud Platform resource
+                names.
 
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -2137,7 +2140,7 @@ class AwsClustersClient(metaclass=AwsClustersClientMeta):
         # Done; return the response.
         return response
 
-    def __enter__(self):
+    def __enter__(self) -> "AwsClustersClient":
         return self
 
     def __exit__(self, type, value, traceback):
