@@ -19,9 +19,7 @@ from typing import Dict, Type
 from .base import AwsClustersTransport
 from .grpc import AwsClustersGrpcTransport
 from .grpc_asyncio import AwsClustersGrpcAsyncIOTransport
-from .rest import AwsClustersRestTransport
-from .rest import AwsClustersRestInterceptor
-
+from .rest import AwsClustersRestInterceptor, AwsClustersRestTransport
 
 # Compile a registry of transports.
 _transport_registry = OrderedDict()  # type: Dict[str, Type[AwsClustersTransport]]
